/***
 * Julia
 * Copyright (C) 2005-2006 INRIA, France Telecom, USTL
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * Contact: Lionel.Seinturier@lifl.fr
 *
 * Author: Lionel Seinturier
 */

package org.objectweb.fractal.juliak.factory;

import org.objectweb.fractal.api.type.InterfaceType;
import org.objectweb.fractal.julia.InitializationContext;
import org.objectweb.fractal.juliak.asm.ClassGenerator;

/**
 * Super class for instance generators.
 * 
 * @author Lionel Seinturier <Lionel.Seinturier@lifl.fr>
 * @since 2.5
 */
public class InstanceGenerator {
    
    public InstanceGenerator( ClassGenerator generator ) {
        this.generator = generator;
    }
    
    /** The class generator associated to this instance generator. */
    protected ClassGenerator generator;

    /**
     * Generate a new instance with the current class generator.
     * 
     * @param it  the interface type used to generate the class
     * @param ic  the context for initializing the generated class
     * @return    the instance generated by the class generator
     */
    public Object generate( InterfaceType it, InitializationContext ic )
    throws org.objectweb.fractal.api.factory.InstantiationException {
        
        Class cl = generator.generate(it,ic);
        
        try {
           Object o = cl.newInstance();
           return o;
        }
        catch (InstantiationException e) {
            throw generateExceptionHandler(e);
        }
        catch (IllegalAccessException e) {
            throw generateExceptionHandler(e);
        }
    }
    
    protected org.objectweb.fractal.api.factory.InstantiationException
        generateExceptionHandler( Exception e ) {
        ClasseDefinitions.get().dumpClasses();
        final String msg = e.getClass().getName()+" "+e.getMessage();
        return new org.objectweb.fractal.api.factory.InstantiationException(msg);
    }

}
